@@ -16,8 +16,6 @@
 #define ISDEBUG false
 #endif
 
-#include "version.h"
-
 #define SPECIAL_WORKSPACE_START (-99)
 
 #define PI 3.14159265358979
@@ -27,6 +25,10 @@
 #define WORKSPACE_INVALID     -1L
 #define WORKSPACE_NOT_CHANGED -101
 
+#define MONITOR_INVALID -1L
+
+#define MIN_WINDOW_SIZE 20.0
+
 #define LISTENER(name)                                                                                                                                                             \
     void               listener_##name(wl_listener*, void*);                                                                                                                       \
     inline wl_listener listen_##name = {.notify = listener_##name}
