@@ -7,16 +7,16 @@ class CLayoutManager {
   public:
     CLayoutManager();
 
-    IHyprLayout* getCurrentLayout();
+    IHyprLayout*             getCurrentLayout();
 
-    void         switchToLayout(std::string);
+    void                     switchToLayout(std::string);
 
-    bool         addLayout(const std::string& name, IHyprLayout* layout);
-    bool         removeLayout(IHyprLayout* layout);
+    bool                     addLayout(const std::string& name, IHyprLayout* layout);
+    bool                     removeLayout(IHyprLayout* layout);
+    std::vector<std::string> getAllLayoutNames();
 
   private:
-    enum HYPRLAYOUTS
-    {
+    enum eHyprLayouts : uint8_t {
         LAYOUT_DWINDLE = 0,
         LAYOUT_MASTER
     };
@@ -25,8 +25,7 @@ class CLayoutManager {
 
     CHyprDwindleLayout                                m_cDwindleLayout;
     CHyprMasterLayout                                 m_cMasterLayout;
-
     std::vector<std::pair<std::string, IHyprLayout*>> m_vLayouts;
 };
 
-inline std::unique_ptr<CLayoutManager> g_pLayoutManager;
\ No newline at end of file
+inline std::unique_ptr<CLayoutManager> g_pLayoutManager;
